==> blesta-5.10.2.zip: blesta/plugins/support_manager/language/de_de/admin_departments.php <==
<?php
/**
 * Admin Departments
 *
 * @package blesta
 * @subpackage blesta.language.de_de
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminDepartments.edit.text_add'] = 'hinzufügen';
$lang['AdminDepartments.edit.text_delete'] = 'Löschen';
$lang['AdminDepartments.edit.heading_default'] = 'Standard';
$lang['AdminDepartments.edit.heading_value'] = 'Wert';
$lang['AdminDepartments.edit.heading_name'] = 'Name';
$lang['AdminDepartments.edit.heading_options'] = 'Optionen';
$lang['AdminDepartments.edit.heading_auto_delete'] = 'Auto-Löschen';
$lang['AdminDepartments.edit.heading_encrypted'] = 'Verschlüsselt';
$lang['AdminDepartments.edit.heading_client_add'] = 'Kunde kann hinzufügen';
$lang['AdminDepartments.edit.heading_step'] = 'Schritt';
$lang['AdminDepartments.edit.heading_max'] = 'Max';
$lang['AdminDepartments.edit.heading_min'] = 'Min';
$lang['AdminDepartments.edit.heading_type'] = 'Typ';
$lang['AdminDepartments.edit.heading_visibility'] = 'Sichtbarkeit';
$lang['AdminDepartments.edit.heading_description'] = 'Beschreibung';
$lang['AdminDepartments.edit.heading_label'] = 'Etikett';
$lang['AdminDepartments.edit.no_results'] = 'In dieser Abteilung gibt es keine benutzerdefinierten Felder.';
$lang['AdminDepartments.edit.confirm_field_remove'] = 'Sind Sie sicher, dass Sie dieses benutzerdefinierte Feld löschen möchten? Alle Daten, die mit diesem Feld verbunden sind, werden gelöscht. Wenn Sie dieses Feld ausblenden und die Daten beibehalten möchten, ändern Sie seine Sichtbarkeit in Nur für Mitarbeiter.';
$lang['AdminDepartments.edit.field_add_field'] = 'Feld hinzufügen';
$lang['AdminDepartments.edit.field_addsubmit'] = 'Abteilung bearbeiten';
$lang['AdminDepartments.edit.field_status'] = 'Status';
$lang['AdminDepartments.edit.field_response_id'] = 'Auto-Close Ticket-Antwort';
$lang['AdminDepartments.edit.field_reminder_ticket_priority'] = 'Erinnerungen an Tickets mit Priorität senden';
$lang['AdminDepartments.edit.field_reminder_ticket_status'] = 'Erinnerungen an Tickets mit Status senden';
$lang['AdminDepartments.edit.field_reminder_ticket_interval'] = 'Automatisch Ticket-Erinnerungen senden';
$lang['AdminDepartments.edit.field_delete_ticket_interval'] = 'Tickets automatisch löschen';
$lang['AdminDepartments.edit.field_close_ticket_interval'] = 'Tickets automatisch schließen';
$lang['AdminDepartments.edit.field_port'] = 'Hafen';
$lang['AdminDepartments.edit.field_pass'] = 'Pass';
$lang['AdminDepartments.edit.field_user'] = 'Benutzer';
$lang['AdminDepartments.edit.field_host'] = 'Gastgeber';
$lang['AdminDepartments.edit.field_mark_messages'] = 'Nachrichten markieren als';
$lang['AdminDepartments.edit.field_box_name'] = 'Name der Box';
$lang['AdminDepartments.edit.field_security'] = 'Sicherheit';
$lang['AdminDepartments.edit.field_max_attachment_size'] = 'Maximale Anbringungsgröße';
$lang['AdminDepartments.edit.field_attachment_types'] = 'Unterstützte Anlagentypen';
$lang['AdminDepartments.edit.field_include_attachments'] = 'Unterstützte Anhänge in Ticket-Benachrichtigungen einbeziehen';
$lang['AdminDepartments.edit.field_default_priority'] = 'Standardpriorität';
$lang['AdminDepartments.edit.field_piping_config'] = 'Konfiguration der Rohrleitungen';
$lang['AdminDepartments.edit.field_method'] = 'E-Mail-Bearbeitung';
$lang['AdminDepartments.edit.field_automatic_transition'] = 'Automatischer Übergang des Ticketstatus bei Antwort des Administrators';
$lang['AdminDepartments.edit.field_send_ticket_received'] = 'Automatische Antwort-E-Mails für neue Tickets senden';
$lang['AdminDepartments.edit.field_override_from_email'] = 'Überschreiben Sie die Absenderadresse in E-Mail-Vorlagen mit der E-Mail-Adresse, die für diese Abteilung festgelegt wurde.';
$lang['AdminDepartments.edit.field_email'] = 'E-Mail';
$lang['AdminDepartments.edit.field_require_captcha'] = 'Erforderliche menschliche Verifizierung für nicht authentifizierte Benutzer';
$lang['AdminDepartments.edit.field_clients_only'] = 'Erlauben Sie nur Kunden, Tickets zu öffnen oder zu beantworten';
$lang['AdminDepartments.edit.field_description'] = 'Beschreibung';
$lang['AdminDepartments.edit.field_name'] = 'Name';
$lang['AdminDepartments.edit.tab_custom_fields'] = 'Benutzerdefinierte Felder';
$lang['AdminDepartments.edit.tab_general'] = 'Allgemein';
$lang['AdminDepartments.edit.boxtitle_adddepartment'] = 'Abteilung bearbeiten';
$lang['AdminDepartments.add.text_add'] = 'hinzufügen';
$lang['AdminDepartments.add.text_delete'] = 'Löschen';
$lang['AdminDepartments.add.heading_default'] = 'Standard';
$lang['AdminDepartments.add.heading_value'] = 'Wert';
$lang['AdminDepartments.add.heading_name'] = 'Name';
$lang['AdminDepartments.add.heading_options'] = 'Optionen';
$lang['AdminDepartments.add.heading_auto_delete'] = 'Auto-Löschen';
$lang['AdminDepartments.add.heading_encrypted'] = 'Verschlüsselt';
$lang['AdminDepartments.add.heading_client_add'] = 'Kunde kann hinzufügen';
$lang['AdminDepartments.add.heading_step'] = 'Schritt';
$lang['AdminDepartments.add.heading_max'] = 'Max';
$lang['AdminDepartments.add.heading_min'] = 'Min';
$lang['AdminDepartments.add.heading_type'] = 'Typ';
$lang['AdminDepartments.add.heading_visibility'] = 'Sichtbarkeit';
$lang['AdminDepartments.add.heading_description'] = 'Beschreibung';
$lang['AdminDepartments.add.heading_label'] = 'Etikett';
$lang['AdminDepartments.add.field_add_field'] = 'Feld hinzufügen';
$lang['AdminDepartments.add.field_addsubmit'] = 'Abteilung hinzufügen';
$lang['AdminDepartments.add.field_status'] = 'Status';
$lang['AdminDepartments.add.field_response_id'] = 'Auto-Close Ticket-Antwort';
$lang['AdminDepartments.add.field_reminder_ticket_priority'] = 'Erinnerungen an Tickets mit Priorität senden';
$lang['AdminDepartments.add.field_reminder_ticket_status'] = 'Erinnerungen an Tickets mit Status senden';
$lang['AdminDepartments.add.field_reminder_ticket_interval'] = 'Automatisch Ticket-Erinnerungen senden';
$lang['AdminDepartments.add.field_delete_ticket_interval'] = 'Tickets automatisch löschen';
$lang['AdminDepartments.add.field_close_ticket_interval'] = 'Tickets automatisch schließen';
$lang['AdminDepartments.add.field_port'] = 'Hafen';
$lang['AdminDepartments.add.field_pass'] = 'Pass';
$lang['AdminDepartments.add.field_user'] = 'Benutzer';
$lang['AdminDepartments.add.field_host'] = 'Gastgeber';
$lang['AdminDepartments.add.field_mark_messages'] = 'Nachrichten markieren als';
$lang['AdminDepartments.add.field_box_name'] = 'Name der Box';
$lang['AdminDepartments.add.field_security'] = 'Sicherheit';
$lang['AdminDepartments.add.field_max_attachment_size'] = 'Maximale Anbringungsgröße';
$lang['AdminDepartments.add.field_attachment_types'] = 'Unterstützte Anlagentypen';
$lang['AdminDepartments.add.field_include_attachments'] = 'Unterstützte Anhänge in Ticket-Benachrichtigungen einbeziehen';
$lang['AdminDepartments.add.field_default_priority'] = 'Standardpriorität';
$lang['AdminDepartments.add.field_piping_config'] = 'Konfiguration der Rohrleitungen';
$lang['AdminDepartments.add.field_method'] = 'E-Mail-Bearbeitung';
$lang['AdminDepartments.add.field_automatic_transition'] = 'Automatischer Übergang des Ticketstatus bei Antwort des Administrators';
$lang['AdminDepartments.add.field_send_ticket_received'] = 'Automatische Antwort-E-Mails für neue Tickets senden';
$lang['AdminDepartments.add.field_override_from_email'] = 'Überschreiben Sie die Absenderadresse in E-Mail-Vorlagen mit der E-Mail-Adresse, die für diese Abteilung festgelegt wurde.';
$lang['AdminDepartments.add.field_email'] = 'E-Mail';
$lang['AdminDepartments.add.field_require_captcha'] = 'Erforderliche menschliche Verifizierung für nicht authentifizierte Benutzer';
$lang['AdminDepartments.add.field_clients_only'] = 'Erlauben Sie nur Kunden, Tickets zu öffnen oder zu beantworten';
$lang['AdminDepartments.add.field_description'] = 'Beschreibung';
$lang['AdminDepartments.add.field_name'] = 'Name';
$lang['AdminDepartments.add.tab_custom_fields'] = 'Benutzerdefinierte Felder';
$lang['AdminDepartments.add.tab_general'] = 'Allgemein';
$lang['AdminDepartments.add.boxtitle_adddepartment'] = 'Abteilung hinzufügen';
$lang['AdminDepartments.!text.remove_response'] = 'entfernen';
$lang['AdminDepartments.!text.no_selected_response'] = 'Keine automatische Schließung ausgewählt.';
$lang['AdminDepartments.!text.add_response'] = 'Eine vordefinierte Reaktion auf das automatische Schließen festlegen';
$lang['AdminDepartments.!tooltip.auto_delete'] = 'Wenn das Ticket geschlossen wird, werden die Felddaten automatisch gelöscht. Die Daten sind dann für die Mitarbeiter nicht mehr sichtbar.';
$lang['AdminDepartments.!tooltip.client_add'] = 'Ob der Kunde das Feld übermitteln kann oder nicht; bei false kann der Kunde das Feld nur lesen.';
$lang['AdminDepartments.!tooltip.max_attachment_size'] = 'Maximale Größe des beizufügenden Anhangs in MB.';
$lang['AdminDepartments.!tooltip.attachment_types'] = 'Liste der unterstützten Erweiterungen, getrennt durch Komma (z.B. zip,jpg,png).';
$lang['AdminDepartments.!tooltip.include_attachments'] = 'Mailserver haben Beschränkungen für die Größe von Anhängen und Dateitypen. Um das Risiko zu verringern, dass eine E-Mail abgelehnt wird, sollten Sie den Typ und die Größe der Anhänge einschränken. Um sicherzugehen, dass der Kunde weiß, welche Anhänge nicht mitgeschickt wurden, verwenden Sie das Tag {ticket.reply_has_attachments} in Ticket-Benachrichtigungen.';
$lang['AdminDepartments.!tooltip.automatic_transition'] = 'Ändert den Status in %1$s, wenn ein Mitarbeiter antwortet.';
$lang['AdminDepartments.!tooltip.send_ticket_received'] = 'Wenn Sie dieses Kontrollkästchen deaktivieren, wird bei neuen Tickets, die für diese Abteilung (per E-Mail oder Client) erstellt werden, keine Antwortbenachrichtigung an den Kunden bzw. Mitarbeiter über die E-Mail "Ticket erhalten" oder "Ticket aktualisiert" gesendet.';
$lang['AdminDepartments.!tooltip.reminder_ticket_interval'] = 'Für alle Tickets mit einem anderen Status als %1$s wird eine Erinnerung an den anderen Teil gesendet, wenn innerhalb der gewählten Zeitspanne keine Antwort erfolgt ist.';
$lang['AdminDepartments.!tooltip.delete_ticket_interval'] = 'Alle Tickets mit dem Status %1$s werden automatisch gelöscht, nachdem sie für die ausgewählte Zeitspanne in diesem Status geblieben sind.';
$lang['AdminDepartments.!tooltip.close_ticket_interval'] = 'Alle Tickets mit einem anderen Status als %1$s, deren letzte Antwort von einem Mitarbeiter stammt, werden automatisch geschlossen, wenn innerhalb der gewählten Zeitspanne keine Antwort erfolgt ist.';
$lang['AdminDepartments.!tooltip.piping_config'] = 'Legen Sie den Piping-Pfad wie gezeigt fest, aber stellen Sie sicher, dass Sie den richtigen Pfad zu PHP auf Ihrem Server verwenden. Stellen Sie sicher, dass pipe.php ausführbar ist. Möglicherweise müssen Sie auch pipe.php bearbeiten, um einen Hashbang in Zeile 1 einzufügen, der etwa so aussehen würde: #!/usr/bin/php';
$lang['AdminDepartments.assigned_staff.no_results'] = 'Dieser Abteilung ist kein Personal zugewiesen.';
$lang['AdminDepartments.assigned_staff.heading_staff'] = 'Personal';
$lang['AdminDepartments.assigned_staff.heading_assigned_staff'] = 'Zugewiesenes Personal';
$lang['AdminDepartments.index.no_results'] = 'Es gibt keine Abteilungen.';
$lang['AdminDepartments.index.confirm_delete'] = 'Abteilungen, denen Tickets zugewiesen sind, können erst gelöscht werden, wenn alle Tickets einer anderen Abteilung zugewiesen wurden. Sind Sie sicher, dass Sie diese Abteilung löschen möchten?';
$lang['AdminDepartments.index.option_delete'] = 'Löschen';
$lang['AdminDepartments.index.option_edit'] = 'bearbeiten';
$lang['AdminDepartments.index.heading_options'] = 'Optionen';
$lang['AdminDepartments.index.heading_default_priority'] = 'Standardpriorität';
$lang['AdminDepartments.index.heading_assigned_staff'] = 'Zugewiesenes Personal';
$lang['AdminDepartments.index.heading_email'] = 'E-Mail';
$lang['AdminDepartments.index.heading_description'] = 'Beschreibung';
$lang['AdminDepartments.index.heading_name'] = 'Name';
$lang['AdminDepartments.index.boxtitle_departments'] = 'Abteilungen';
$lang['AdminDepartments.index.categorylink_adddepartment'] = 'Abteilung hinzufügen';
$lang['AdminDepartments.edit.page_title'] = 'Support Manager > Abteilungen > Abteilung bearbeiten';
$lang['AdminDepartments.add.page_title'] = 'Support Manager > Abteilungen > Abteilung hinzufügen';
$lang['AdminDepartments.index.page_title'] = 'Support Manager > Abteilungen';
$lang['AdminDepartments.!success.department_deleted'] = 'Die Abteilung %1$s wurde erfolgreich gelöscht.';
$lang['AdminDepartments.!success.department_updated'] = 'Die Abteilung %1$s wurde erfolgreich aktualisiert.';
$lang['AdminDepartments.!success.department_created'] = 'Die Abteilung %1$s wurde erfolgreich erstellt.';

==> blesta-5.11.4.zip: blesta/plugins/support_manager/language/de_de/admin_departments.php <==
<?php
/**
 * Admin Departments
 *
 * @package blesta
 * @subpackage blesta.language.de_de
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminDepartments.edit.text_add'] = 'hinzufügen';
$lang['AdminDepartments.edit.text_delete'] = 'Löschen';
$lang['AdminDepartments.edit.heading_default'] = 'Standard';
$lang['AdminDepartments.edit.heading_value'] = 'Wert';
$lang['AdminDepartments.edit.heading_name'] = 'Name';
$lang['AdminDepartments.edit.heading_options'] = 'Optionen';
$lang['AdminDepartments.edit.heading_auto_delete'] = 'Auto-Löschen';
$lang['AdminDepartments.edit.heading_encrypted'] = 'Verschlüsselt';
$lang['AdminDepartments.edit.heading_client_add'] = 'Kunde kann hinzufügen';
$lang['AdminDepartments.edit.heading_step'] = 'Schritt';
$lang['AdminDepartments.edit.heading_max'] = 'Max';
$lang['AdminDepartments.edit.heading_min'] = 'Min';
$lang['AdminDepartments.edit.heading_type'] = 'Typ';
$lang['AdminDepartments.edit.heading_visibility'] = 'Sichtbarkeit';
$lang['AdminDepartments.edit.heading_description'] = 'Beschreibung';
$lang['AdminDepartments.edit.heading_label'] = 'Etikett';
$lang['AdminDepartments.edit.no_results'] = 'In dieser Abteilung gibt es keine benutzerdefinierten Felder.';
$lang['AdminDepartments.edit.confirm_field_remove'] = 'Sind Sie sicher, dass Sie dieses benutzerdefinierte Feld löschen möchten? Alle Daten, die mit diesem Feld verbunden sind, werden gelöscht. Wenn Sie dieses Feld ausblenden und die Daten beibehalten möchten, ändern Sie seine Sichtbarkeit in Nur für Mitarbeiter.';
$lang['AdminDepartments.edit.field_add_field'] = 'Feld hinzufügen';
$lang['AdminDepartments.edit.field_addsubmit'] = 'Abteilung bearbeiten';
$lang['AdminDepartments.edit.field_status'] = 'Status';
$lang['AdminDepartments.edit.field_response_id'] = 'Auto-Close Ticket-Antwort';
$lang['AdminDepartments.edit.field_reminder_ticket_priority'] = 'Erinnerungen an Tickets mit Priorität senden';
$lang['AdminDepartments.edit.field_reminder_ticket_status'] = 'Erinnerungen an Tickets mit Status senden';
$lang['AdminDepartments.edit.field_reminder_ticket_interval'] = 'Automatisch Ticket-Erinnerungen senden';
$lang['AdminDepartments.edit.field_delete_ticket_interval'] = 'Tickets automatisch löschen';
$lang['AdminDepartments.edit.field_close_ticket_interval'] = 'Tickets automatisch schließen';
$lang['AdminDepartments.edit.field_port'] = 'Hafen';
$lang['AdminDepartments.edit.field_pass'] = 'Pass';
$lang['AdminDepartments.edit.field_user'] = 'Benutzer';
$lang['AdminDepartments.edit.field_host'] = 'Gastgeber';
$lang['AdminDepartments.edit.field_mark_messages'] = 'Nachrichten markieren als';
$lang['AdminDepartments.edit.field_box_name'] = 'Name der Box';
$lang['AdminDepartments.edit.field_security'] = 'Sicherheit';
$lang['AdminDepartments.edit.field_max_attachment_size'] = 'Maximale Anbringungsgröße';
$lang['AdminDepartments.edit.field_attachment_types'] = 'Unterstützte Anlagentypen';
$lang['AdminDepartments.edit.field_include_attachments'] = 'Unterstützte Anhänge in Ticket-Benachrichtigungen einbeziehen';
$lang['AdminDepartments.edit.field_default_priority'] = 'Standardpriorität';
$lang['AdminDepartments.edit.field_piping_config'] = 'Konfiguration der Rohrleitungen';
$lang['AdminDepartments.edit.field_method'] = 'E-Mail-Bearbeitung';
$lang['AdminDepartments.edit.field_automatic_transition'] = 'Automatischer Übergang des Ticketstatus bei Antwort des Administrators';
$lang['AdminDepartments.edit.field_send_ticket_received'] = 'Automatische Antwort-E-Mails für neue Tickets senden';
$lang['AdminDepartments.edit.field_override_from_email'] = 'Überschreiben Sie die Absenderadresse in E-Mail-Vorlagen mit der E-Mail-Adresse, die für diese Abteilung festgelegt wurde.';
$lang['AdminDepartments.edit.field_email'] = 'E-Mail';
$lang['AdminDepartments.edit.field_require_captcha'] = 'Erforderliche menschliche Verifizierung für nicht authentifizierte Benutzer';
$lang['AdminDepartments.edit.field_clients_only'] = 'Erlauben Sie nur Kunden, Tickets zu öffnen oder zu beantworten';
$lang['AdminDepartments.edit.field_description'] = 'Beschreibung';
$lang['AdminDepartments.edit.field_name'] = 'Name';
$lang['AdminDepartments.edit.tab_custom_fields'] = 'Benutzerdefinierte Felder';
$lang['AdminDepartments.edit.tab_general'] = 'Allgemein';
$lang['AdminDepartments.edit.boxtitle_adddepartment'] = 'Abteilung bearbeiten';
$lang['AdminDepartments.add.text_add'] = 'hinzufügen';
$lang['AdminDepartments.add.text_delete'] = 'Löschen';
$lang['AdminDepartments.add.heading_default'] = 'Standard';
$lang['AdminDepartments.add.heading_value'] = 'Wert';
$lang['AdminDepartments.add.heading_name'] = 'Name';
$lang['AdminDepartments.add.heading_options'] = 'Optionen';
$lang['AdminDepartments.add.heading_auto_delete'] = 'Auto-Löschen';
$lang['AdminDepartments.add.heading_encrypted'] = 'Verschlüsselt';
$lang['AdminDepartments.add.heading_client_add'] = 'Kunde kann hinzufügen';
$lang['AdminDepartments.add.heading_step'] = 'Schritt';
$lang['AdminDepartments.add.heading_max'] = 'Max';
$lang['AdminDepartments.add.heading_min'] = 'Min';
$lang['AdminDepartments.add.heading_type'] = 'Typ';
$lang['AdminDepartments.add.heading_visibility'] = 'Sichtbarkeit';
$lang['AdminDepartments.add.heading_description'] = 'Beschreibung';
$lang['AdminDepartments.add.heading_label'] = 'Etikett';
$lang['AdminDepartments.add.field_add_field'] = 'Feld hinzufügen';
$lang['AdminDepartments.add.field_addsubmit'] = 'Abteilung hinzufügen';
$lang['AdminDepartments.add.field_status'] = 'Status';
$lang['AdminDepartments.add.field_response_id'] = 'Auto-Close Ticket-Antwort';
$lang['AdminDepartments.add.field_reminder_ticket_priority'] = 'Erinnerungen an Tickets mit Priorität senden';
$lang['AdminDepartments.add.field_reminder_ticket_status'] = 'Erinnerungen an Tickets mit Status senden';
$lang['AdminDepartments.add.field_reminder_ticket_interval'] = 'Automatisch Ticket-Erinnerungen senden';
$lang['AdminDepartments.add.field_delete_ticket_interval'] = 'Tickets automatisch löschen';
$lang['AdminDepartments.add.field_close_ticket_interval'] = 'Tickets automatisch schließen';
$lang['AdminDepartments.add.field_port'] = 'Hafen';
$lang['AdminDepartments.add.field_pass'] = 'Pass';
$lang['AdminDepartments.add.field_user'] = 'Benutzer';
$lang['AdminDepartments.add.field_host'] = 'Gastgeber';
$lang['AdminDepartments.add.field_mark_messages'] = 'Nachrichten markieren als';
$lang['AdminDepartments.add.field_box_name'] = 'Name der Box';
$lang['AdminDepartments.add.field_security'] = 'Sicherheit';
$lang['AdminDepartments.add.field_max_attachment_size'] = 'Maximale Anbringungsgröße';
$lang['AdminDepartments.add.field_attachment_types'] = 'Unterstützte Anlagentypen';
$lang['AdminDepartments.add.field_include_attachments'] = 'Unterstützte Anhänge in Ticket-Benachrichtigungen einbeziehen';
$lang['AdminDepartments.add.field_default_priority'] = 'Standardpriorität';
$lang['AdminDepartments.add.field_piping_config'] = 'Konfiguration der Rohrleitungen';
$lang['AdminDepartments.add.field_method'] = 'E-Mail-Bearbeitung';
$lang['AdminDepartments.add.field_automatic_transition'] = 'Automatischer Übergang des Ticketstatus bei Antwort des Administrators';
$lang['AdminDepartments.add.field_send_ticket_received'] = 'Automatische Antwort-E-Mails für neue Tickets senden';
$lang['AdminDepartments.add.field_override_from_email'] = 'Überschreiben Sie die Absenderadresse in E-Mail-Vorlagen mit der E-Mail-Adresse, die für diese Abteilung festgelegt wurde.';
$lang['AdminDepartments.add.field_email'] = 'E-Mail';
$lang['AdminDepartments.add.field_require_captcha'] = 'Erforderliche menschliche Verifizierung für nicht authentifizierte Benutzer';
$lang['AdminDepartments.add.field_clients_only'] = 'Erlauben Sie nur Kunden, Tickets zu öffnen oder zu beantworten';
$lang['AdminDepartments.add.field_description'] = 'Beschreibung';
$lang['AdminDepartments.add.field_name'] = 'Name';
$lang['AdminDepartments.add.tab_custom_fields'] = 'Benutzerdefinierte Felder';
$lang['AdminDepartments.add.tab_general'] = 'Allgemein';
$lang['AdminDepartments.add.boxtitle_adddepartment'] = 'Abteilung hinzufügen';
$lang['AdminDepartments.!text.remove_response'] = 'entfernen';
$lang['AdminDepartments.!text.no_selected_response'] = 'Keine automatische Schließung ausgewählt.';
$lang['AdminDepartments.!text.add_response'] = 'Eine vordefinierte Reaktion auf das automatische Schließen festlegen';
$lang['AdminDepartments.!tooltip.auto_delete'] = 'Wenn das Ticket geschlossen wird, werden die Felddaten automatisch gelöscht. Die Daten sind dann für die Mitarbeiter nicht mehr sichtbar.';
$lang['AdminDepartments.!tooltip.client_add'] = 'Ob der Kunde das Feld übermitteln kann oder nicht; bei false kann der Kunde das Feld nur lesen.';
$lang['AdminDepartments.!tooltip.max_attachment_size'] = 'Maximale Größe des beizufügenden Anhangs in MB.';
$lang['AdminDepartments.!tooltip.attachment_types'] = 'Liste der unterstützten Erweiterungen, getrennt durch Komma (z.B. zip,jpg,png).';
$lang['AdminDepartments.!tooltip.include_attachments'] = 'Mailserver haben Beschränkungen für die Größe von Anhängen und Dateitypen. Um das Risiko zu verringern, dass eine E-Mail abgelehnt wird, sollten Sie den Typ und die Größe der Anhänge einschränken. Um sicherzugehen, dass der Kunde weiß, welche Anhänge nicht mitgeschickt wurden, verwenden Sie das Tag {ticket.reply_has_attachments} in Ticket-Benachrichtigungen.';
$lang['AdminDepartments.!tooltip.automatic_transition'] = 'Ändert den Status in %1$s, wenn ein Mitarbeiter antwortet.';
$lang['AdminDepartments.!tooltip.send_ticket_received'] = 'Wenn Sie dieses Kontrollkästchen deaktivieren, wird bei neuen Tickets, die für diese Abteilung (per E-Mail oder Client) erstellt werden, keine Antwortbenachrichtigung an den Kunden bzw. Mitarbeiter über die E-Mail "Ticket erhalten" oder "Ticket aktualisiert" gesendet.';
$lang['AdminDepartments.!tooltip.reminder_ticket_interval'] = 'Für alle Tickets mit einem anderen Status als %1$s wird eine Erinnerung an den anderen Teil gesendet, wenn innerhalb der gewählten Zeitspanne keine Antwort erfolgt ist.';
$lang['AdminDepartments.!tooltip.delete_ticket_interval'] = 'Alle Tickets mit dem Status %1$s werden automatisch gelöscht, nachdem sie für die ausgewählte Zeitspanne in diesem Status geblieben sind.';
$lang['AdminDepartments.!tooltip.close_ticket_interval'] = 'Alle Tickets mit einem anderen Status als %1$s, deren letzte Antwort von einem Mitarbeiter stammt, werden automatisch geschlossen, wenn innerhalb der gewählten Zeitspanne keine Antwort erfolgt ist.';
$lang['AdminDepartments.!tooltip.piping_config'] = 'Legen Sie den Piping-Pfad wie gezeigt fest, aber stellen Sie sicher, dass Sie den richtigen Pfad zu PHP auf Ihrem Server verwenden. Stellen Sie sicher, dass pipe.php ausführbar ist. Möglicherweise müssen Sie auch pipe.php bearbeiten, um einen Hashbang in Zeile 1 einzufügen, der etwa so aussehen würde: #!/usr/bin/php';
$lang['AdminDepartments.assigned_staff.no_results'] = 'Dieser Abteilung ist kein Personal zugewiesen.';
$lang['AdminDepartments.assigned_staff.heading_staff'] = 'Personal';
$lang['AdminDepartments.assigned_staff.heading_assigned_staff'] = 'Zugewiesenes Personal';
$lang['AdminDepartments.index.no_results'] = 'Es gibt keine Abteilungen.';
$lang['AdminDepartments.index.confirm_delete'] = 'Abteilungen, denen Tickets zugewiesen sind, können erst gelöscht werden, wenn alle Tickets einer anderen Abteilung zugewiesen wurden. Sind Sie sicher, dass Sie diese Abteilung löschen möchten?';
$lang['AdminDepartments.index.option_delete'] = 'Löschen';
$lang['AdminDepartments.index.option_edit'] = 'bearbeiten';
$lang['AdminDepartments.index.heading_options'] = 'Optionen';
$lang['AdminDepartments.index.heading_default_priority'] = 'Standardpriorität';
$lang['AdminDepartments.index.heading_assigned_staff'] = 'Zugewiesenes Personal';
$lang['AdminDepartments.index.heading_email'] = 'E-Mail';
$lang['AdminDepartments.index.heading_description'] = 'Beschreibung';
$lang['AdminDepartments.index.heading_name'] = 'Name';
$lang['AdminDepartments.index.boxtitle_departments'] = 'Abteilungen';
$lang['AdminDepartments.index.categorylink_adddepartment'] = 'Abteilung hinzufügen';
$lang['AdminDepartments.edit.page_title'] = 'Support Manager > Abteilungen > Abteilung bearbeiten';
$lang['AdminDepartments.add.page_title'] = 'Support Manager > Abteilungen > Abteilung hinzufügen';
$lang['AdminDepartments.index.page_title'] = 'Support Manager > Abteilungen';
$lang['AdminDepartments.!success.department_deleted'] = 'Die Abteilung %1$s wurde erfolgreich gelöscht.';
$lang['AdminDepartments.!success.department_updated'] = 'Die Abteilung %1$s wurde erfolgreich aktualisiert.';
$lang['AdminDepartments.!success.department_created'] = 'Die Abteilung %1$s wurde erfolgreich erstellt.';
$lang['AdminDepartments.edit.field_priorities'] = 'Verfügbare Prioritäten';
$lang['AdminDepartments.add.field_priorities'] = 'Verfügbare Prioritäten';
$lang['AdminDepartments.edit.field_force_import'] = 'Import erzwingen';
$lang['AdminDepartments.add.field_force_import'] = 'Import erzwingen';
$lang['AdminDepartments.!success.department_imported'] = 'Die Abteilung %1$s wurde erfolgreich importiert.';
